best_hit_taxonomy_assignment: Hierarchical best-hit taxonomy assignment with per-rank...

View source: R/Best_Assingment.R

best_hit_taxonomy_assignmentR Documentation

Hierarchical best-hit taxonomy assignment with per-rank fallback rule

Description

Pass ONLY those OTUs that haven't been assigned already! For each rank, if the best e-value hit is undefined and the second-best hit is defined and at least 60

Usage

best_hit_taxonomy_assignment(blast_qc, cutoffs_long, defaults)

Arguments

blast_qc

A data.frame of BLAST results for query sequences, must include columns for taxonomic ranks and alignment statistics.

cutoffs_long

A data.frame specifying per-rank cutoffs for assignment. Must include columns 'rank', 'cutoff_type', and 'cutoff_value'.

defaults

A named list of default cutoff values for each rank, used as fallback if no matching cutoff found.

Value

A data.frame containing hierarchical taxonomy assignment for each query sequence.


ClassifyITS documentation built on April 9, 2026, 5:08 p.m.