View source: R/Consensus_taxonomy.R
| write_initial_assignments | R Documentation |
Create and write the initial assignments table including drops at all steps
write_initial_assignments(
easy_df,
consensus_df,
rep_seqs,
blast,
blast_filtered,
file = NULL,
verbose = FALSE
)
easy_df |
Data frame of easy-assigned OTUs |
consensus_df |
Data frame of consensus-assigned OTUs (hard ones) |
rep_seqs |
DNAStringSet or named character vector of rep seqs |
blast |
Data frame of all BLAST results |
blast_filtered |
Data frame of filtered BLAST results |
file |
Path for output CSV. If NULL (default), no file is written. |
verbose |
Logical; if TRUE emit a message when a file is written. Default FALSE. |
Data frame of assignments (written if file is not NULL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.